@@ -161,7 +161,8 @@ static int s_TestIotPublishSubscribe(Aws::Crt::Allocator *allocator, void *ctx)
         bool published = false;
         bool received = false;
         bool closed = false;
-        auto onConnectionCompleted = [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent) {
+        auto onConnectionCompleted = [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent)
+        {
             printf(
                 "%s errorCode=%d returnCode=%d sessionPresent=%d\n",
                 (errorCode == 0) ? "CONNECTED" : "COMPLETED",
@@ -174,7 +175,8 @@ static int s_TestIotPublishSubscribe(Aws::Crt::Allocator *allocator, void *ctx)
             }
             cv.notify_one();
         };
-        auto onDisconnect = [&](MqttConnection &) {
+        auto onDisconnect = [&](MqttConnection &)
+        {
             printf("DISCONNECTED\n");
             {
                 std::lock_guard<std::mutex> lock(mutex);
@@ -182,7 +184,8 @@ static int s_TestIotPublishSubscribe(Aws::Crt::Allocator *allocator, void *ctx)
             }
             cv.notify_one();
         };
-        auto onTest = [&](MqttConnection &, const Aws::Crt::String &topic, const Aws::Crt::ByteBuf &payload) {
+        auto onTest = [&](MqttConnection &, const Aws::Crt::String &topic, const Aws::Crt::ByteBuf &payload)
+        {
             printf("GOT MESSAGE topic=%s payload=" PRInSTR "\n", topic.c_str(), AWS_BYTE_BUF_PRI(payload));
             {
                 std::lock_guard<std::mutex> lock(mutex);
@@ -190,7 +193,8 @@ static int s_TestIotPublishSubscribe(Aws::Crt::Allocator *allocator, void *ctx)
             }
             cv.notify_one();
         };
-        auto onSubAck = [&](MqttConnection &, uint16_t packetId, const Aws::Crt::String &topic, QOS qos, int) {
+        auto onSubAck = [&](MqttConnection &, uint16_t packetId, const Aws::Crt::String &topic, QOS qos, int)
+        {
             printf("SUBACK id=%d topic=%s qos=%d\n", packetId, topic.c_str(), qos);
             {
                 std::lock_guard<std::mutex> lock(mutex);
@@ -198,7 +202,8 @@ static int s_TestIotPublishSubscribe(Aws::Crt::Allocator *allocator, void *ctx)
             }
             cv.notify_one();
         };
-        auto onPubAck = [&](MqttConnection &, uint16_t packetId, int) {
+        auto onPubAck = [&](MqttConnection &, uint16_t packetId, int)
+        {
             printf("PUBLISHED id=%d\n", packetId);
             {
                 std::lock_guard<std::mutex> lock(mutex);
@@ -206,7 +211,8 @@ static int s_TestIotPublishSubscribe(Aws::Crt::Allocator *allocator, void *ctx)
             }
             cv.notify_one();
         };
-        auto onConnectionClosed = [&](MqttConnection &, OnConnectionClosedData *data) {
+        auto onConnectionClosed = [&](MqttConnection &, OnConnectionClosedData *data)
+        {
             (void)data;
             printf("CLOSED\n");
             {
@@ -322,7 +328,8 @@ static int s_TestIotConnectionSuccessTest(Aws::Crt::Allocator *allocator, void *
     bool connection_success = false;
     bool closed = false;
 
-    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData *data) {
+    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData *data)
+    {
         {
             std::lock_guard<std::mutex> lock(mutex);
             connection_success = true;
@@ -331,7 +338,8 @@ static int s_TestIotConnectionSuccessTest(Aws::Crt::Allocator *allocator, void *
         cv.notify_one();
     };
 
-    auto onConnectionClosed = [&](MqttConnection &, OnConnectionClosedData *data) {
+    auto onConnectionClosed = [&](MqttConnection &, OnConnectionClosedData *data)
+    {
         (void)data;
         printf("CLOSED");
         {
@@ -417,7 +425,8 @@ static int s_TestIotConnectionFailureTest(Aws::Crt::Allocator *allocator, void *
     std::mutex mutex;
     std::condition_variable cv;
     bool connection_failure = false;
-    auto onConnectionFailure = [&](MqttConnection &, OnConnectionFailureData *data) {
+    auto onConnectionFailure = [&](MqttConnection &, OnConnectionFailureData *data)
+    {
         printf("CONNECTION FAILURE: error=%i\n", data->error);
         {
             std::lock_guard<std::mutex> lock(mutex);
@@ -500,17 +509,19 @@ static int s_TestIotWillTest(Aws::Crt::Allocator *allocator, void *ctx)
         std::condition_variable willCv;
         bool willConnected = false;
         auto willOnConnectionCompleted =
-            [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent) {
-                (void)errorCode;
-                (void)returnCode;
-                (void)sessionPresent;
-                {
-                    std::lock_guard<std::mutex> lock(willMutex);
-                    willConnected = true;
-                }
-                willCv.notify_one();
-            };
-        auto willOnDisconnect = [&](MqttConnection &) {
+            [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent)
+        {
+            (void)errorCode;
+            (void)returnCode;
+            (void)sessionPresent;
+            {
+                std::lock_guard<std::mutex> lock(willMutex);
+                willConnected = true;
+            }
+            willCv.notify_one();
+        };
+        auto willOnDisconnect = [&](MqttConnection &)
+        {
             {
                 std::lock_guard<std::mutex> lock(willMutex);
                 willConnected = false;
@@ -533,17 +544,19 @@ static int s_TestIotWillTest(Aws::Crt::Allocator *allocator, void *ctx)
         bool subscriberSubscribed = false;
         bool subscriberReceived = false;
         auto subscriberOnConnectionCompleted =
-            [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent) {
-                (void)errorCode;
-                (void)returnCode;
-                (void)sessionPresent;
-                {
-                    std::lock_guard<std::mutex> lock(subscriberMutex);
-                    subscriberConnected = true;
-                }
-                subscriberCv.notify_one();
-            };
-        auto subscriberOnDisconnect = [&](MqttConnection &) {
+            [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent)
+        {
+            (void)errorCode;
+            (void)returnCode;
+            (void)sessionPresent;
+            {
+                std::lock_guard<std::mutex> lock(subscriberMutex);
+                subscriberConnected = true;
+            }
+            subscriberCv.notify_one();
+        };
+        auto subscriberOnDisconnect = [&](MqttConnection &)
+        {
             {
                 std::lock_guard<std::mutex> lock(subscriberMutex);
                 subscriberConnected = false;
@@ -551,18 +564,19 @@ static int s_TestIotWillTest(Aws::Crt::Allocator *allocator, void *ctx)
                 subscriberCv.notify_one();
             }
         };
-        auto subscriberOnSubAck =
-            [&](MqttConnection &, uint16_t packetId, const Aws::Crt::String &topic, QOS qos, int) {
-                (void)packetId;
-                (void)topic;
-                (void)qos;
-                {
-                    std::lock_guard<std::mutex> lock(subscriberMutex);
-                    subscriberSubscribed = true;
-                }
-                subscriberCv.notify_one();
-            };
-        auto subscriberOnTest = [&](MqttConnection &, const Aws::Crt::String &topic, const Aws::Crt::ByteBuf &payload) {
+        auto subscriberOnSubAck = [&](MqttConnection &, uint16_t packetId, const Aws::Crt::String &topic, QOS qos, int)
+        {
+            (void)packetId;
+            (void)topic;
+            (void)qos;
+            {
+                std::lock_guard<std::mutex> lock(subscriberMutex);
+                subscriberSubscribed = true;
+            }
+            subscriberCv.notify_one();
+        };
+        auto subscriberOnTest = [&](MqttConnection &, const Aws::Crt::String &topic, const Aws::Crt::ByteBuf &payload)
+        {
             (void)topic;
             (void)payload;
             {
@@ -593,17 +607,19 @@ static int s_TestIotWillTest(Aws::Crt::Allocator *allocator, void *ctx)
         std::condition_variable interruptCv;
         bool interruptConnected = false;
         auto interruptOnConnectionCompleted =
-            [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent) {
-                (void)errorCode;
-                (void)returnCode;
-                (void)sessionPresent;
-                {
-                    std::lock_guard<std::mutex> lock(interruptMutex);
-                    interruptConnected = true;
-                }
-                interruptCv.notify_one();
-            };
-        auto interruptOnDisconnect = [&](MqttConnection &) {
+            [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent)
+        {
+            (void)errorCode;
+            (void)returnCode;
+            (void)sessionPresent;
+            {
+                std::lock_guard<std::mutex> lock(interruptMutex);
+                interruptConnected = true;
+            }
+            interruptCv.notify_one();
+        };
+        auto interruptOnDisconnect = [&](MqttConnection &)
+        {
             {
                 std::lock_guard<std::mutex> lock(interruptMutex);
                 interruptConnected = false;
@@ -696,7 +712,8 @@ static int s_TestIotStatisticsPublishWaitStatisticsDisconnect(Aws::Crt::Allocato
         std::condition_variable cv;
         bool connected = false;
         bool published = false;
-        auto onConnectionCompleted = [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent) {
+        auto onConnectionCompleted = [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent)
+        {
             printf(
                 "%s errorCode=%d returnCode=%d sessionPresent=%d\n",
                 (errorCode == 0) ? "CONNECTED" : "COMPLETED",
@@ -709,7 +726,8 @@ static int s_TestIotStatisticsPublishWaitStatisticsDisconnect(Aws::Crt::Allocato
             }
             cv.notify_one();
         };
-        auto onDisconnect = [&](MqttConnection &) {
+        auto onDisconnect = [&](MqttConnection &)
+        {
             printf("DISCONNECTED\n");
             {
                 std::lock_guard<std::mutex> lock(mutex);
@@ -718,7 +736,8 @@ static int s_TestIotStatisticsPublishWaitStatisticsDisconnect(Aws::Crt::Allocato
                 cv.notify_one();
             }
         };
-        auto onPubAck = [&](MqttConnection &, uint16_t packetId, int) {
+        auto onPubAck = [&](MqttConnection &, uint16_t packetId, int)
+        {
             printf("PUBLISHED id=%d\n", packetId);
             {
                 std::lock_guard<std::mutex> lock(mutex);
@@ -826,7 +845,8 @@ static int s_TestIotStatisticsPublishStatisticsWaitDisconnect(Aws::Crt::Allocato
         std::condition_variable cv;
         bool connected = false;
         bool published = false;
-        auto onConnectionCompleted = [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent) {
+        auto onConnectionCompleted = [&](MqttConnection &, int errorCode, ReturnCode returnCode, bool sessionPresent)
+        {
             printf(
                 "%s errorCode=%d returnCode=%d sessionPresent=%d\n",
                 (errorCode == 0) ? "CONNECTED" : "COMPLETED",
@@ -839,7 +859,8 @@ static int s_TestIotStatisticsPublishStatisticsWaitDisconnect(Aws::Crt::Allocato
             }
             cv.notify_one();
         };
-        auto onDisconnect = [&](MqttConnection &) {
+        auto onDisconnect = [&](MqttConnection &)
+        {
             printf("DISCONNECTED\n");
             {
                 std::lock_guard<std::mutex> lock(mutex);
@@ -848,7 +869,8 @@ static int s_TestIotStatisticsPublishStatisticsWaitDisconnect(Aws::Crt::Allocato
                 cv.notify_one();
             }
         };
-        auto onPubAck = [&](MqttConnection &, uint16_t packetId, int) {
+        auto onPubAck = [&](MqttConnection &, uint16_t packetId, int)
+        {
             printf("PUBLISHED id=%d\n", packetId);
             {
                 std::lock_guard<std::mutex> lock(mutex);
@@ -961,7 +983,8 @@ static int s_TestIotConnectionDestruction(Aws::Crt::Allocator *allocator, void *
     std::condition_variable cv;
     bool connection_success = false;
 
-    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData *data) {
+    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData *data)
+    {
         {
             std::lock_guard<std::mutex> lock(mutex);
             connection_success = true;
@@ -1043,7 +1066,8 @@ static int s_TestIotConnectionDestructionWithExecutingCallback(Aws::Crt::Allocat
     bool connectionSuccess = false;
     bool disconnectingStarted = false;
 
-    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData *data) {
+    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData *data)
+    {
         {
             std::lock_guard<std::mutex> lock(mutex);
             connectionSuccess = true;
@@ -1054,7 +1078,8 @@ static int s_TestIotConnectionDestructionWithExecutingCallback(Aws::Crt::Allocat
 
     mqttConnection->OnConnectionSuccess = onConnectionSuccess;
 
-    mqttConnection->OnDisconnect = [&](MqttConnection &) {
+    mqttConnection->OnDisconnect = [&](MqttConnection &)
+    {
         {
             std::lock_guard<std::mutex> lock(mutex);
             disconnectingStarted = true;
@@ -1143,7 +1168,8 @@ static int s_TestIotConnectionDestructionWithinConnectionCallback(Aws::Crt::Allo
     std::condition_variable cv;
     bool connection_success = false;
 
-    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData *data) {
+    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData *data)
+    {
         // Destroy mqtt connection object.
         mqttConnection.reset();
 
@@ -1225,7 +1251,8 @@ static int s_TestIotConnectionDestructionWithinDisconnectCallback(Aws::Crt::Allo
     bool connectionSuccess = false;
     bool disconnected = false;
 
-    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData *data) {
+    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData *data)
+    {
         {
             std::lock_guard<std::mutex> lock(mutex);
             connectionSuccess = true;
@@ -1236,7 +1263,8 @@ static int s_TestIotConnectionDestructionWithinDisconnectCallback(Aws::Crt::Allo
 
     mqttConnection->OnConnectionSuccess = onConnectionSuccess;
 
-    mqttConnection->OnDisconnect = [&](MqttConnection &) {
+    mqttConnection->OnDisconnect = [&](MqttConnection &)
+    {
         // Destroy mqtt connection object.
         mqttConnection.reset();
         {
@@ -1321,7 +1349,8 @@ static int s_TestIotConnectionDestructionWithPublish(Aws::Crt::Allocator *alloca
     std::condition_variable cv;
     bool connected = false;
     bool published = false;
-    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData * /*data*/) {
+    auto onConnectionSuccess = [&](MqttConnection &, OnConnectionSuccessData * /*data*/)
+    {
         {
             std::lock_guard<std::mutex> lock(mutex);
             connected = true;
@@ -1341,7 +1370,8 @@ static int s_TestIotConnectionDestructionWithPublish(Aws::Crt::Allocator *alloca
 
     // Publish data.
     Aws::Crt::ByteBuf payload = Aws::Crt::ByteBufFromCString("notice me pls");
-    auto onPubAck = [&](MqttConnection &connection, uint16_t packetId, int) {
+    auto onPubAck = [&](MqttConnection &connection, uint16_t packetId, int)
+    {
         {
             std::lock_guard<std::mutex> lock(mutex);
             published = true;
